@@ -17,8 +17,7 @@ from .external.six.moves import range
 
 
 def _index_to_label(index):
-    """Convert a pandas index or multiindex to an axis label
-    """
+    """Convert a pandas index or multiindex to an axis label."""
     if isinstance(index, pd.MultiIndex):
         return "-".join(map(str, index.names))
     else:
@@ -26,14 +25,25 @@ def _index_to_label(index):
 
 
 def _index_to_ticklabels(index):
-    """Convert a pandas index or multiindex into ticklabels
-    """
+    """Convert a pandas index or multiindex into ticklabels."""
     if isinstance(index, pd.MultiIndex):
         return ["-".join(map(str, i)) for i in index.values]
     else:
         return index.values
 
 
+def _convert_colors(colors):
+    """Convert either a list of colors or nested lists of colors to RGB."""
+    to_rgb = mpl.colors.colorConverter.to_rgb
+    try:
+        to_rgb(colors[0])
+        # If this works, there is only one level of colors
+        return list(map(to_rgb, colors))
+    except ValueError:
+        # If we get here, we have nested lists
+        return [list(map(to_rgb, l)) for l in colors]
+
+
 class _HeatMapper(object):
     """Draw a heatmap plot of a matrix with nice labels and colormaps."""
 
@@ -52,6 +62,11 @@ class _HeatMapper(object):
         # Reverse the rows so the plot looks like the matrix
         plot_data = plot_data[::-1]
         data = data.ix[::-1]
+        if mask is not None:
+            try:
+                mask = mask.ix[::-1]
+            except AttributeError:
+                mask = mask[::-1]
 
         plot_data = np.ma.masked_where(mask, plot_data)
 
@@ -248,6 +263,9 @@ def heatmap(data, vmin=None, vmax=None, cmap=None, center=None, robust=False,
         If True, plot the row names of the dataframe. If False, don't plot
         the row names. If list-like, plot these alternate labels as the
         yticklabels
+    mask : boolean numpy.array, optional
+        A boolean array indicating where to mask the data so it is not
+        plotted on the heatmap. Only used for visualizing, not for calculating.
     kwargs : other keyword arguments
         All other keyword arguments are passed to ``ax.pcolormesh``.
 
@@ -503,12 +521,11 @@ class ClusterGrid(Grid):
             figsize = (width, height)
         self.fig = plt.figure(figsize=figsize)
 
-        to_rgb = mpl.colors.colorConverter.to_rgb
         if row_colors is not None:
-            row_colors = list(map(to_rgb, row_colors))
+            row_colors = _convert_colors(row_colors)
         self.row_colors = row_colors
         if col_colors is not None:
-            col_colors = list(map(to_rgb, col_colors))
+            col_colors = _convert_colors(col_colors)
         self.col_colors = col_colors
 
         width_ratios = self.dim_ratios(self.row_colors,
