@@ -149,6 +149,20 @@ class TestHeatmap(object):
         nt.assert_equal(m1.vmin, m2.vmin)
         nt.assert_equal(m1.vmax, m2.vmax)
 
+    def test_mask(self):
+
+        df = pd.DataFrame(data={'a': [1, 1, 1],
+                                'b': [2, np.nan, 2],
+                                'c': [3, 3, np.nan]})
+
+        kws = self.default_kws.copy()
+        kws["mask"] = np.isnan(df.values)
+
+        m = mat._HeatMapper(df, **kws)
+
+        npt.assert_array_equal(np.isnan(m.plot_data.data),
+                               m.plot_data.mask)
+
     def test_custom_cmap(self):
 
         kws = self.default_kws.copy()
@@ -601,6 +615,21 @@ class TestClustermap(object):
         nt.assert_equal(len(cm.fig.axes), 6)
         plt.close('all')
 
+    def test_nested_colors_input(self):
+        kws = self.default_kws.copy()
+
+        row_colors = [self.row_colors, self.row_colors]
+        col_colors = [self.col_colors, self.col_colors]
+        kws['row_colors'] = row_colors
+        kws['col_colors'] = col_colors
+
+        cm = mat.ClusterGrid(self.df_norm, **kws)
+        npt.assert_array_equal(cm.row_colors, row_colors)
+        npt.assert_array_equal(cm.col_colors, col_colors)
+
+        nt.assert_equal(len(cm.fig.axes), 6)
+        plt.close('all')
+
     def test_colors_input_custom_cmap(self):
         kws = self.default_kws.copy()
 
